==> dasu_4.11.jar: edu/northwestern/dasu/drools/FactMeasurementDss.java <==
/**
 * Dasu Project
 *
 * File:         FactMeasurementDss.java
 * RCS:          $Id$
 * Description:  FactMeasurementDss class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 21, 2010 at 10:05:08 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import edu.northwestern.dasu.stats.DownloadStatsSummary;
import org.gudy.azureus2.plugins.download.Download;

/* 
 */
/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactMeasurementDss class ...
 * For an member to be visible to Drools (as part of the fact)  
 * it must have it's own public setter and getter functions
 */

public class FactMeasurementDss extends FactMeasurement<DownloadStatsSummary> {
	
		private Download download;
		private long downloadingTime;
		private long seedingTime;
		private int maxDownloadRateLimit;
		private int maxUploadLimit;
		private long totalUploaded;
		private long totalDownloaded;
		private long size;
		private int downloadId;
		private int priority;
		private long pieceSize;
		private String downloadName;	
	
		public FactMeasurementDss() {
			
		}
		
		public FactMeasurementDss(DownloadStatsSummary dss) {
			
			this.download = dss.download;
			this.size = dss.size;
			this.downloadId = dss.downloadId;
			this.downloadName = dss.downloadName;
			this.downloadingTime = dss.downloadingTime;
			this.seedingTime = dss.seedingTime; 
			this.maxDownloadRateLimit = dss.maxDownloadRateLimit;
			this.maxUploadLimit = dss.maxUploadLimit;
			this.totalUploaded = dss.totalUploaded;
			this.totalDownloaded = dss.totalDownloaded;
			this.priority = dss.priority;
			this.pieceSize = dss.pieceSize;
			
			addEntry(dss);
		}
		
		@Override
		public void updateAll(DownloadStatsSummary dss) {
			
			this.download = dss.download;
			this.size = dss.size;
			this.downloadId = dss.downloadId;
			this.downloadName = dss.downloadName;
			this.downloadingTime = dss.downloadingTime;
			this.seedingTime = dss.seedingTime; 
			this.maxDownloadRateLimit = dss.maxDownloadRateLimit;
			this.maxUploadLimit = dss.maxUploadLimit;
			this.totalUploaded = dss.totalUploaded;
			this.totalDownloaded = dss.totalDownloaded;
			this.priority = dss.priority;
			this.pieceSize = dss.pieceSize;
		
			
			if (DEBUG) {

				StringBuilder sb = new StringBuilder();
				
				sb.append("MEASUREMENT: FactMeasurementDss\n");
				for (int i = 0; i < entryList.size(); i++ ) {
					sb.append(entryList.get(i).timeRecorded + " size " +
							entryList.get(i).size + " totalDownloaded " + 
							entryList.get(i).totalDownloaded + " totalUploaded " + 
							entryList.get(i).totalUploaded + "\n");
				}
				LOGGER.info(sb.toString());
			}
			
		}	
		
		public Download getDownload() {
			return download;
		}

		public long getDownloadingTime() {
			return downloadingTime;
		}

		public long getSeedingTime() {
			return seedingTime;
		}

		public int getMaxDownloadRateLimit() {
			return maxDownloadRateLimit;
		}

		public int getMaxUploadLimit() {
			return maxUploadLimit;
		}

		public long getTotalUploaded() {
			return totalUploaded;
		}

		public long getTotalDownloaded() {
			return totalDownloaded;
		}

		public long getSize() {
			return size;
		}

		public int getDownloadId() {
			return downloadId;
		}

		public int getPriority() {
			return priority;
		}

		public long getPieceSize() {
			return pieceSize;
		}

		public String getDownloadName() {
			return downloadName;
		}
		
		public void setDownload(Download download) {
			this.download = download;
		}
		
		public void setDownloadingTime(long downloadingTime) {
			Long temp = this.downloadingTime;
			this.downloadingTime = downloadingTime;
	        pcs.firePropertyChange("downloadingTime", new Long(temp), new Long(downloadingTime));
		}

		public void setSeedingTime(long seedingTime) {
			Long temp = this.seedingTime;
			this.seedingTime = seedingTime;
	        pcs.firePropertyChange("seedingTime", new Long(temp), new Long(seedingTime));
		}		

		public void setMaxDownloadRateLimit(Integer maxDownloadRateLimit) {
			Integer temp = this.maxDownloadRateLimit;
			this.maxDownloadRateLimit = maxDownloadRateLimit;
	        pcs.firePropertyChange("maxDownloadRateLimit", new Integer(temp), new Integer(maxDownloadRateLimit));
		}


		public void setMaxUploadLimit(Integer maxUploadLimit) {
			Integer temp = this.maxUploadLimit;
			this.maxUploadLimit = maxUploadLimit;
	        pcs.firePropertyChange("maxUploadLimit", new Integer(temp), new Integer(maxUploadLimit));
		}

		public void setTotalUploaded(long totalUploaded) {
			Long temp = this.totalUploaded;
			this.totalUploaded = totalUploaded;
	        pcs.firePropertyChange("totalUploaded", new Long(temp), new Long(totalUploaded));
		}		

		public void setTotalDownloaded(long totalDownloaded) {
			Long temp = this.totalDownloaded;
			this.totalDownloaded = totalDownloaded;
	        pcs.firePropertyChange("totalDownloaded", new Long(temp), new Long(totalDownloaded));
		}		

		public void setSize(long size) {
			Long temp = this.size;
			this.size = size;
	        pcs.firePropertyChange("size", new Long(temp), new Long(size));
		}		
		
		public void setDownloadId(Integer downloadId) {
			Integer temp = this.downloadId;
			this.downloadId = downloadId;
	        pcs.firePropertyChange("maxDownloadRateLimit", new Integer(temp), new Integer(downloadId));
		}

		public void setPriority(Integer priority) {
			Integer temp = this.priority;
			this.priority = priority;
	        pcs.firePropertyChange("priority", new Integer(temp), new Integer(priority));
		}

		public void setPieceSize(long pieceSize) {
			Long temp = this.pieceSize;
			this.pieceSize = pieceSize;
	        pcs.firePropertyChange("pieceSize", new Long(temp), new Long(pieceSize));
		}		

		public void setDownloadName(String downloadName) {
			String temp = this.downloadName;
			this.downloadName = downloadName;
	        pcs.firePropertyChange("pieceSize", new String(temp), new String(downloadName));
		}		

        
}

==> dasu_5.31.jar: edu/northwestern/dasu/drools/FactMeasurementDss.java <==
/**
 * Dasu Project
 *
 * File:         FactMeasurementDss.java
 * RCS:          $Id$
 * Description:  FactMeasurementDss class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 21, 2010 at 10:05:08 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import edu.northwestern.dasu.stats.DownloadStatsSummary;
import org.gudy.azureus2.plugins.download.Download;

/* 
 */
/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactMeasurementDss class ...
 * For an member to be visible to Drools (as part of the fact)  
 * it must have it's own public setter and getter functions
 */

public class FactMeasurementDss extends FactMeasurement<DownloadStatsSummary> {
	
		private Download download;
		public long downloadingTime;
		public long seedingTime;
		public int maxDownloadRateLimit;
		public int maxUploadLimit;
		public long totalUploaded;
		public long totalDownloaded;
		public long size;
		public int downloadId;
		public int priority;
		public long pieceSize;
		private String downloadName;	
	
		public FactMeasurementDss() {
			
		}
		
		public FactMeasurementDss(DownloadStatsSummary dss) {
			
			this.download = dss.download;
			this.size = dss.size;
			this.downloadId = dss.downloadId;
			this.downloadName = dss.downloadName;
			this.downloadingTime = dss.downloadingTime;
			this.seedingTime = dss.seedingTime; 
			this.maxDownloadRateLimit = dss.maxDownloadRateLimit;
			this.maxUploadLimit = dss.maxUploadLimit;
			this.totalUploaded = dss.totalUploaded;
			this.totalDownloaded = dss.totalDownloaded;
			this.priority = dss.priority;
			this.pieceSize = dss.pieceSize;
			
			addEntry(dss);
		}
		
		@Override
		public void updateAll(DownloadStatsSummary dss) {
			
			this.download = dss.download;
			this.size = dss.size;
			this.downloadId = dss.downloadId;
			this.downloadName = dss.downloadName;
			this.downloadingTime = dss.downloadingTime;
			this.seedingTime = dss.seedingTime; 
			this.maxDownloadRateLimit = dss.maxDownloadRateLimit;
			this.maxUploadLimit = dss.maxUploadLimit;
			this.totalUploaded = dss.totalUploaded;
			this.totalDownloaded = dss.totalDownloaded;
			this.priority = dss.priority;
			this.pieceSize = dss.pieceSize;
		
			
			if (DEBUG) {

				StringBuilder sb = new StringBuilder();
				
				sb.append("MEASUREMENT: FactMeasurementDss\n");
				for (int i = 0; i < entryList.size(); i++ ) {
					sb.append(entryList.get(i).timeRecorded + " size " +
							entryList.get(i).size + " totalDownloaded " + 
							entryList.get(i).totalDownloaded + " totalUploaded " + 
							entryList.get(i).totalUploaded + "\n");
				}
				LOGGER.info(sb.toString());
			}
			
		}	
		
		public Download getDownload() {
			return download;
		}

		public long getDownloadingTime() {
			return downloadingTime;
		}

		public long getSeedingTime() {
			return seedingTime;
		}

		public int getMaxDownloadRateLimit() {
			return maxDownloadRateLimit;
		}

		public int getMaxUploadLimit() {
			return maxUploadLimit;
		}

		public long getTotalUploaded() {
			return totalUploaded;
		}

		public long getTotalDownloaded() {
			return totalDownloaded;
		}

		public long getSize() {
			return size;
		}

		public int getDownloadId() {
			return downloadId;
		}

		public int getPriority() {
			return priority;
		}

		public long getPieceSize() {
			return pieceSize;
		}

		public String getDownloadName() {
			return downloadName;
		}
		
		public void setDownload(Download download) {
			this.download = download;
		}
		
		public void setDownloadingTime(long downloadingTime) {
			Long temp = this.downloadingTime;
			this.downloadingTime = downloadingTime;
	        pcs.firePropertyChange("downloadingTime", new Long(temp), new Long(downloadingTime));
		}

		public void setSeedingTime(long seedingTime) {
			Long temp = this.seedingTime;
			this.seedingTime = seedingTime;
	        pcs.firePropertyChange("seedingTime", new Long(temp), new Long(seedingTime));
		}		

		public void setMaxDownloadRateLimit(Integer maxDownloadRateLimit) {
			Integer temp = this.maxDownloadRateLimit;
			this.maxDownloadRateLimit = maxDownloadRateLimit;
	        pcs.firePropertyChange("maxDownloadRateLimit", new Integer(temp), new Integer(maxDownloadRateLimit));
		}


		public void setMaxUploadLimit(Integer maxUploadLimit) {
			Integer temp = this.maxUploadLimit;
			this.maxUploadLimit = maxUploadLimit;
	        pcs.firePropertyChange("maxUploadLimit", new Integer(temp), new Integer(maxUploadLimit));
		}

		public void setTotalUploaded(long totalUploaded) {
			Long temp = this.totalUploaded;
			this.totalUploaded = totalUploaded;
	        pcs.firePropertyChange("totalUploaded", new Long(temp), new Long(totalUploaded));
		}		

		public void setTotalDownloaded(long totalDownloaded) {
			Long temp = this.totalDownloaded;
			this.totalDownloaded = totalDownloaded;
	        pcs.firePropertyChange("totalDownloaded", new Long(temp), new Long(totalDownloaded));
		}		

		public void setSize(long size) {
			Long temp = this.size;
			this.size = size;
	        pcs.firePropertyChange("size", new Long(temp), new Long(size));
		}		
		
		public void setDownloadId(Integer downloadId) {
			Integer temp = this.downloadId;
			this.downloadId = downloadId;
	        pcs.firePropertyChange("maxDownloadRateLimit", new Integer(temp), new Integer(downloadId));
		}

		public void setPriority(Integer priority) {
			Integer temp = this.priority;
			this.priority = priority;
	        pcs.firePropertyChange("priority", new Integer(temp), new Integer(priority));
		}

		public void setPieceSize(long pieceSize) {
			Long temp = this.pieceSize;
			this.pieceSize = pieceSize;
	        pcs.firePropertyChange("pieceSize", new Long(temp), new Long(pieceSize));
		}		

		public void setDownloadName(String downloadName) {
			String temp = this.downloadName;
			this.downloadName = downloadName;
	        pcs.firePropertyChange("pieceSize", new String(temp), new String(downloadName));
		}		

        
}
